# ikamand [![Build Status][travis_status]][travis] [![PyPI version][pypi_badge]][pypi]

_Python package for communicating with the iKamand._

Allows local interaction with the iKamand temperature controller.

## Install

```bash
pip install ikamand
```

Look at the file `example.py` for a usage example.

[travis_status]: https://travis-ci.org/slinkymanbyday/ikamand.svg?branch=master
[travis]: https://travis-ci.org/slinkymanbyday/ikamand
[pypi]:https://pypi.org/project/ikamand/
[pypi_badge]: https://badge.fury.io/py/ikamand.svg
